- ntraits
Number of traits to be simulated.
- nenvs
Number of environments to be simulated (minimum of two).
- mean
A vector of mean genetic values for each environment-within-trait combination.
If only one value is specified, all combinations will be assigned the same mean.
- var
A vector of genetic variances for each environment-within-trait combination.
If only one value is specified, all combinations will be assigned
the same variance.
Alternatively, if a separable structure between traits and environments is desired,
Tvar and Evar can be specified.
- Tvar
A vector of genetic variances for each trait. Must be provided in combination with
Evar.
Alternatively, var can be specified.
- Evar
A vector of genetic variances for each environment. Must be provided in
combination with Tvar.
Alternatively, var can be specified.
- corA
A matrix of additive genetic correlations between environment-within-trait
combinations. By default, a diagonal matrix is constructed.
Alternatively, TcorA and EcorA can be specified.
- TcorA
A matrix of additive genetic correlations between traits. Must be provided in
combination with EcorA.
Alternatively, corA can be specified.
- EcorA
A matrix of additive genetic correlations between environments.
Must be provided in combination with TcorA.
Alternatively, corA can be specified.
- meanDD
A vector of mean dominance degrees for each environment-within-trait combination
(similar to mean). If only one value is specified, all
combinations will be assigned the same mean. By default, meanDD = NULL and dominance
is not simulated.
- varDD
A vector of dominance degree variances for each environment-within-trait
combination (similar to var). If only one value is specified, all
combinations will be assigned the same variance.
Alternatively, if a separable structure between traits and environments is desired,
TvarDD and EvarDD can be specified.
- TvarDD
A vector of dominance degree variances for each trait (similar to Tvar).
Must be provided in combination with EvarDD.
Alternatively, varDD can be specified.
- EvarDD
A vector of dominance degree variances for each environment (similar to
Evar). Must be provided in combination with TvarDD.
Alternatively, varDD can be specified.
- corDD
A matrix of dominance degree correlations between environment-within-trait
combinations (similar to corA). If not specified and dominance is simulated, a
diagonal matrix is constructed.
Alternatively, TcorDD and EcorDD can be specified.
- TcorDD
A matrix of dominance degree correlations between traits (similar to
TcorA). Must be provided in combination with EcorDD.
Alternatively, corDD can be specified.
- EcorDD
A matrix of dominance degree correlations between environments (similar to
EcorA). Must be provided in combination with TcorDD.
Alternatively, corDD can be specified.
- relAA
A vector defining the relative magnitude of additive-by-additive (epistatic) variance
to additive genetic variance for each environment-within-trait combination,
that is in a diploid organism with allele frequency of 0.5. If only one value is specified,
all environment-within-trait combinations will be assigned the same value. By default,
relAA = NULL and epistasis is not simulated.
Alternatively, if a separable structure between traits and environments is desired,
TrelAA and ErelAA can be specified.
- TrelAA
A vector defining the relative magnitude of epistatic variance
to additive genetic variance for each trait. Must be provided in combination
with ErelAA.
Alternatively, relAA can be specified.
- ErelAA
A vector defining the relative magnitude of epistatic variance
to additive genetic variance for each environment. Must be provided in
combination with TrelAA.
Alternatively, relAA can be specified.
- corAA
A matrix of epistatic correlations between environment-within-trait
combinations (similar to corA). If not specified and epistasis is simulated, a
diagonal matrix is constructed.
Alternatively, TcorAA and EcorAA can be specified.
- TcorAA
A matrix of epistatic correlations between traits (similar to TcorA).
Must be provided in combination with EcorAA.
Alternatively, corAA can be specified.
- EcorAA
A matrix of epistatic correlations between environments (similar to
EcorA). Must be provided in combination with TcorAA.
Alternatively, corAA can be specified.